@@ -67,6 +67,25 @@ class SequentialHead(EncoderHead):
             "output_size": self._output_size,
         }
 
+    def transform(self, input_vectors: torch.Tensor) -> torch.Tensor:
+        return input_vectors
+
+    def save(self, output_path):
+        torch.save(self._sequential, os.path.join(output_path, "weights.bin"))
+
+        with open(os.path.join(output_path, "config.json"), "w") as f_out:
+            json.dump(self.get_config_dict(), f_out, indent=2)
+
+    @classmethod
+    def load(cls, input_path: str) -> "EncoderHead":
+        with open(os.path.join(input_path, "config.json")) as f_in:
+            config = json.load(f_in)
+        sequential = torch.load(
+            os.path.join(input_path, "weights.bin"), map_location="cpu"
+        )
+        model = cls(*sequential, **config)
+        return model
+
     def __getitem__(self, idx) -> Union[nn.Sequential, nn.Module]:
         return self._sequential[idx]
 
@@ -84,19 +103,3 @@ class SequentialHead(EncoderHead):
 
     def __iter__(self) -> Iterator[nn.Module]:
         return self._sequential.__iter__()
-
-    def save(self, output_path):
-        torch.save(self._sequential, os.path.join(output_path, "weights.bin"))
-
-        with open(os.path.join(output_path, "config.json"), "w") as f_out:
-            json.dump(self.get_config_dict(), f_out, indent=2)
-
-    @classmethod
-    def load(cls, input_path: str) -> "EncoderHead":
-        with open(os.path.join(input_path, "config.json")) as f_in:
-            config = json.load(f_in)
-        sequential = torch.load(
-            os.path.join(input_path, "weights.bin"), map_location="cpu"
-        )
-        model = cls(*sequential, **config)
-        return model
