@@ -3,19 +3,18 @@ from __future__ import annotations
 import json
 import os
 from functools import partial
-from typing import Dict, List, Type, Callable, Any, Union
+from typing import Any, Callable, Dict, List, Type, Union
 
 import numpy as np
 import torch
 from torch import nn
 
 from quaterion_models.encoders import Encoder
-from quaterion_models.types import TensorInterchange, CollateFnType
 from quaterion_models.heads.encoder_head import EncoderHead
-from quaterion_models.utils.classes import save_class_import, restore_class
+from quaterion_models.types import CollateFnType, TensorInterchange
+from quaterion_models.utils.classes import restore_class, save_class_import
 from quaterion_models.utils.tensors import move_to_device
 
-
 DEFAULT_ENCODER_KEY = "default"
 
 
